# Description

This project aims to create a new machine learning framework. The main goal is not to copy already existing frameworks such as TensorFlow, sklearn and Torch, but rather to gain experience and knowledge creating something similar.

Planned features, not in order of importance or priority:

  * Numpy-based sequential API with dense layers
  * Optimization algorithms
  * New layers
  * Low-level operations (switch from numpy to custom code on either C or C++)
  * Impulse neural network with new class for this
  * .ipynb documentation
  * Example models built with this API

This list is to be updated in the future.

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/the-swaggers/recpulse)
